# $gre_
GRE vocab helper

## install

#### from pypi

Run `pip install gre`

#### from source

- Clone repo/download as zip
- `cd` to the folder
- Run `pipenv install`
- Run `pipenv shell`
- Run `pip install .`

## usage

```

Usage: gre [OPTIONS] COMMAND [ARGS]...

  A handy helper to manage GRE Vocab preparation

Options:
  --debug / --no-debug
  --help                Show this message and exit.

Commands:
  add     Add a word/words to vocabulary
  export  Export vocabulary to file
  flash   Flash cards
  get     Retrieve a word, definiton from vocabulary
  nuke    Delete entire vocabulary
  remove  Remove a word/words from vocabulary
  show    Print entire vocabulary

```

## author
Sayan Goswami (c) 2018
